@@ -19,13 +19,15 @@ import sys
 import traceback
 from contextlib import contextmanager
 from io import StringIO
-from typing import TYPE_CHECKING, Any, Iterator
+from typing import TYPE_CHECKING, Any
 
 from pytkdocs import debug
 from pytkdocs.loader import Loader
 from pytkdocs.serializer import serialize_object
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator
+
     from pytkdocs.objects import Object
 
 
