@@ -2,10 +2,11 @@
 
 import ast
 import inspect
+from collections.abc import Iterator
 from functools import lru_cache
 from textwrap import dedent
 from types import ModuleType
-from typing import Any, Callable, Iterator, List, get_type_hints
+from typing import Any, Callable, get_type_hints
 
 try:
     from ast import unparse  # type: ignore[attr-defined]
@@ -15,7 +16,7 @@ except ImportError:
 RECURSIVE_NODES = (ast.If, ast.IfExp, ast.Try, ast.With)
 
 
-def get_nodes(obj: Any) -> List[ast.stmt]:  # noqa: D103
+def get_nodes(obj: Any) -> list[ast.stmt]:  # noqa: D103
     try:
         source = inspect.getsource(obj)
     except (OSError, TypeError):
@@ -46,7 +47,7 @@ def get_pairs(nodes: list) -> Iterator[tuple]:  # noqa: D103
         node1 = nodes[index]
         node2 = nodes[index + 1] if index < len(nodes) - 1 else None
         if isinstance(node1, (ast.Assign, ast.AnnAssign)):
-            if isinstance(node2, ast.Expr) and isinstance(node2.value, ast.Str):
+            if isinstance(node2, ast.Expr) and isinstance(node2.value, ast.Constant):
                 yield node1, node2.value
                 index += 2
             else:
@@ -66,7 +67,7 @@ def get_pairs(nodes: list) -> Iterator[tuple]:  # noqa: D103
 def get_module_or_class_attributes(nodes: list) -> dict:  # noqa: D103
     result = {}
     for assignment, string_node in get_pairs(nodes):
-        string = inspect.cleandoc(string_node.s) if string_node else None
+        string = inspect.cleandoc(string_node.value) if string_node else None
         if isinstance(assignment, ast.Assign):
             names = []
             for target in assignment.targets:
@@ -147,7 +148,7 @@ def get_instance_attributes(func: Callable) -> dict:  # noqa: D103
         if not names or (string is None and annotation is None):
             continue
 
-        docstring = inspect.cleandoc(string.s) if string else None
+        docstring = inspect.cleandoc(string.value) if string else None
         for name in names:
             result[name] = {"annotation": annotation, "docstring": docstring}
 
