@@ -1,7 +1,5 @@
 """The parsers' package."""
 
-from typing import Dict, Type
-
 from pytkdocs.parsers.docstrings.base import Parser, UnavailableParser
 from pytkdocs.parsers.docstrings.google import Google
 from pytkdocs.parsers.docstrings.markdown import Markdown
@@ -15,7 +13,7 @@ except ImportError:
     )
 
 
-PARSERS: Dict[str, Type[Parser]] = {
+PARSERS: dict[str, type[Parser]] = {
     "google": Google,
     "restructured-text": RestructuredText,
     "numpy": Numpy,
