@@ -1,9 +1,10 @@
 """This module simply defines regular expressions and their associated predicates."""
 
 import re
-from typing import Callable, Pattern, Tuple
+from re import Pattern
+from typing import Callable
 
-ApplicableNameProperty = Tuple[str, Callable[[str], bool]]
+ApplicableNameProperty = tuple[str, Callable[[str], bool]]
 
 # exactly two leading underscores, exactly two trailing underscores
 # since we enforce one non-underscore after the two leading underscores,
