@@ -1,8 +1,9 @@
 """Tests for [the `parsers.docstrings.google` module][pytkdocs.parsers.docstrings.google]."""
 
 import inspect
+from collections.abc import Iterator
 from textwrap import dedent
-from typing import Any, Iterator, List, Optional, Tuple
+from typing import Any, Optional
 
 from pytkdocs.loader import Loader
 from pytkdocs.parsers.docstrings.base import Section
@@ -10,7 +11,7 @@ from pytkdocs.parsers.docstrings.google import Google
 from pytkdocs.serializer import serialize_attribute
 
 
-class DummyObject:  # noqa: D101
+class DummyObject:
     path = "o"
 
 
@@ -21,7 +22,7 @@ def parse(
     *,
     admonitions: bool = True,
     trim_doctest: bool = False,
-) -> Tuple[List[Section], List[str]]:
+) -> tuple[list[Section], list[str]]:
     """Helper to parse a doctring."""
     parser = Google(replace_admonitions=admonitions, trim_doctest_flags=trim_doctest)
 
@@ -734,7 +735,7 @@ def test_docstring_with_yield_section_and_return_annotation() -> None:
     sections, errors = parse(inspect.getdoc(f), inspect.signature(f))  # type: ignore[arg-type]
     assert len(sections) == 2
     annotated = sections[1].value
-    assert annotated.annotation is Iterator[int]
+    assert annotated.annotation == Iterator[int]
     assert annotated.description == "Integers."
     assert not errors
 
